function data=mphevalglobalmatrix(model,expr,varargin)
% MPHEVALGLOBALMATRIX Evaluate global matrix variables
%
%   M = MPHEVALGLOBALMATRIX(MODEL, EXPR, ...) evaluates the global matrix 
%   of the variable EXPR and returns the full matrix M.  
%
%   This is useful for extracting S-parameters matrix from a model.
%
%   Valid property/value pairs include:
%   Property        Value/{Default}            Description
%   -----------------------------------------------------------------------
%   dataset         String {''}                Data set tag
%   dataseries      {'none'} | 'average' |     Data series operation
%                   'sum'
%   outerdataseries {'none'} | 'average' |     Outer data series operation
%                   'sum'
%   outersolnum     Integer vector {1} |       Solution number for 
%                   'first' | 'last' | 'all'   parametric sweep
%   solnum          Integer vector |           Solution for evaluation
%                   'end' | {'all'}
%   t               Double array {''}          Time for evaluation
%   trans           {None} | inverse | sy |    Matrix transformation
%                   sz | ys | yz | zs | zy |
%                   maxwellmutual | 
%                   mutualmaxwell
%   y0              Double array               If Trans is sy or ys: the
%                                              characteristic admittance
%   z0              Double array               If Trans is sz or zs: the
%                                              characteristic impedance
%
%   Note: S-parameter evaluation requires the RF Module.
%
%   Example:
%     % Load lossy_circulator_3d.mph from the RF Module's Model library
%     model = mphopen('lossy_circulator_3d');
%     % Evaluate the S-parameters matrix using the solution data set dset4:  
%     M = mphevalglobalmatrix(model, 'emw.SdB', 'dataset', 'dset4')
%
%   See also: mpheval, mphevalpoint, mphevalpointmatrix, mphglobal, mphint2, 
%   mphinterp

%   Copyright 2012-2019 COMSOL
