function [value,unit,def,descr]=mphevaluate(model,expr,inunit,asvalue)
% MPHEVALUATE Evaluate parameter expressions (constants) in models
%
%   MPHEVALUATE(MODEL,EXPR) evaluates the expression EXPR defined in the
%   Parameters node.
%
%   [VALUE,UNIT,DEF,DESCR] = MPHEVALUATE(MODEL,EXPR,...) evaluates the
%   expression EXPR and returns the unit (UNIT), the definition in the model
%   (DEF) and the description (DESCR).
%
%   [VALUE,...] = MPHEVALUATE(MODEL,EXPR,UNIT) evaluates the expression
%   EXPR in the unit defined by UNIT.
%
%   If EXPR is a cell array with expressions only a single output is
%   permitted and an array of structs is returned. This array has the same
%   size as expr.
%
%   [VALUE,...] = MPHEVALUATE(MODEL,EXPR,...,ASVALUE) evaluates the expression
%   EXPR depending on the value of ASVALUE:
%    'value'    : only the value
%    'unit'     : only the unit
%    'valueunit': both value and unit (as a string)
%
%   The evaluation does not require an existing solution data set in the
%   model.
%
%   Example:
%     % Evaluate the parameter power defined in the model:
%     model = mphopen('model_tutorial_llmatlab');
%     power = mphevaluate(model,'power');
%     % Evaluate Temp in degrees Celsius and its definition in the model:
%     [Temp,unit,def] = mphevaluate(model,'Temp','degC');
%     % Evaluate an expression of parameters:
%     Temp = mphevaluate(model,'Temp+20[degC]','degF');
%
%   See also: mphgetexpressions, mphglobal, mphinterp

% Copyright 2013-2019 COMSOL
