function mphgeom(model,geomtag,varargin)
% MPHGEOM Plot a geometry in a MATLAB figure
%
%   MPHGEOM(MODEL) plots the model geometry in a MATLAB figure.
%
%   MPHGEOM(MODEL,GEOMTAG,...) plots the model geometry with the tag
%   GEOMTAG in a MATLAB figure.
%
%   Valid property/value pairs include:
%   Property           Value/{Default}     Description
%   -----------------------------------------------------------------------
%   build              {'on'} | 'off' |    Build the geometry before
%                      'current' | string  plotting
%   domainlabels       'on'|{'off'}        Show domain labels
%   domainlabelscolor  char|{'k'}          Color for domain labels
%   edgecolor          char {'k'}          Edge color
%   edgelabels         'on'|{'off'}        Show edge labels
%   edgelabelscolor    char {'k'}          Color for edge labels
%   edgemode           {'on'} | 'off'      Show edges
%   entity             'point' | 'edge' |  Geometric entity to select
%                      'boundary' | 
%                      'domain'
%   facealpha          Double {1}          Set transparency value
%   facecolor          char | {'gray'}     Face color
%   facelabels         'on' | {'off'}      Show face labels
%   facelabelscolor    char | {'k'}        Color for face labels
%   facemode           {'on'} | 'off'      Show faces
%   parent             Double              Parent axis
%   selection          Positive integer    Selection
%                      array | {[]}
%   vertexlabels       'on' | {'off'}      Show vertex labels
%   vertexlabelscolor  char | {'r'}        Color for vertex labels
%   vertexmode         'on' | {'off'}      Show vertices
%   view               String | {''} |     View settings
%                      'auto'
%   workplane          String              Workplane name
%
%   The Build property determines if MPHGEOM build the geometry prior to
%   display it. If the Build property is set with a geometric object tag,
%   the geometry is built up to that object. MPHGEOM only displays built
%   geometry objects.
%
%   Example:
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab.mph');
%     % Plot the model geometry:
%     mphgeom(model)
%
%     % Plot the model geometry with face labels:
%     mphgeom(model,'geom1','facelabels','on','facelabelscolor','r');
%
%     % Plot boundaries 7, 8, 9 and 11:
%     mphgeom(model,'geom1','entity','boundary','selection',[7:9,11]);
%
%     % Plot the model geometry on the current axis:
%     figure(2);
%     mphgeom(model,'geom1','parent',gca);
%
%   See also: mphmesh, mphviewselection

%   Copyright 2010-2019 COMSOL
