function pd=mphquad2tri(pd)
% MPHQUAD2TRI Convert plot data quad mesh into simplex mesh
%
%   PDOUT = MPHQUAD2TRI(PDIN) converts the plot data stored in the structure 
%   PDIN into the structure PDOUT using a simplex mesh.
%
%   The input and output structures, respectively PDIN and PDOUT, are structures 
%   with fields described below:
%   Field          Description
%   -----------------------------------------------------------------------
%   p              2xN array containing the vertex coordinates.
%   d              Nx1 array containing the data value at the vertices.
%   t              Array containing the indices to columns in p of a quad 
%                  mesh for PDIN and of a simplex mesh for PDOUT, each 
%                  column in t representing respectively a quad and a simplex. 
%   rgb(*)         Nx3 array containing the color model data. 
%   expr(*)        String containing the description of the data. 
%
%   (*) This field is optional in PDIN.
%
%  Example:
%    % Generate 3D surf data: 
%    [x,y] = meshgrid(-0.1:0.2:1.1,-0.4:0.2:0.4);
%    z = cumsum(0.1*randn(size(x)));
%    % Create plotdata in a quad mesh:
%    pd = mphsurf(x,y,z);
%    % Convert the plot data into triangle mesh:
%    pd = mphquad2tri(pd);
%    mphplot(pd)
%
%   See also: mphsurf, mphreadstl, mphwritestl

% Copyright 2012-2019 COMSOL
