function n=mphselectbox(model,geomtag,coord,entity,varargin)
% MPHSELECTBOX Select geometric entity using a rubberband/box
% 
%   N = MPHSELECTBOX(MODEL,GEOMTAG,BOXCOORD,ENTITY,...) returns the 
%   indices of the geometric entities that are inside the rubberband domain
%   (rectangle or box). This method looks only on the vertex coordinates
%   and does not observe all points on curves and surfaces.
% 
%   BOXCOORD set the coordinates of the selection domain, specified as a 
%   Nx2 array, where N is the geometry space dimension.
%   ENTITY can be one of 'point', 'edge', 'boundary' or 'domain'. See the 
%   entry MPHSELECTBOX in the LiveLink for MATLAB User's Guide for more 
%   information about the entity type definition.
% 
%   Valid property/value pairs include:
%   Property     Value/{Default}            Description
%   -----------------------------------------------------------------------
%   adjnumber    Scalar {[]}                Adjacent entity number
% 
%   When a model uses "form an assembly" more than one vertex may have the
%   same coordinate if the coordinate is shared be separate geometric
%   objects. In that case one can use the adjnumber property in order to 
%   identify the domain that the vertices should be adjacent to.
%
%   Example 1: 
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%
%     % Find the domains within the box defined delimited by
%     % [-1e-3 11e-3;-1e-3 11e-3;9e-3 11e-3]:
%     coordBox = [-1e-3 11e-3;-1e-3 11e-3;9e-3 11e-3];
%     n = mphselectbox(model,'geom1',coordBox,'domain')
%
%     % Find the boundaries inside the selection box:
%     n = mphselectbox(model,'geom1',coordBox,'boundary')
%
%     % Find the boundaries inside the selection box that are adjacent to
%     % domain number 1:
%     n = mphselectbox(model,'geom1',coordBox,'boundary','adjnumber',1)
%
%   Example 2: Find geometry entity number in an assembly
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Finalize the geometry as an assembly:
%     model.geom('geom1').feature('fin').set('action', 'assembly');
%     model.geom('geom1').run('fin');
%
%     % Find the boundaries within a box:
%     coordBox = [-1e-3,51e-3;-1e-3,51e-3;9e-3,11e-3];
%     n = mphselectbox(model,'geom1',coordBox,'boundary')
%
%     % Find the boundary adjacent to domain 2:
%     n = mphselectbox(model,'geom1',coordBox,'boundary','adjnumber',1)
% 
%   See also: mphgetadj, mphgetcoords, mphselectcoords, mphviewselection

%   Copyright 2010-2019 COMSOL
