function data=mphstate(model,soltag,varargin)
% MPHSTATE Get state space matrices for a dynamic system
% 
%   STR = MPHSTATE(MODEL,SOLTAG,'out',{'SP'}) returns a MATLAB structure 
%   STR containing the state space matrix SP assembled using the solver 
%   node defined with the tag SOLTAG and accessible as STR.SP. SP being 
%   taken from the Out property list.
% 
%   STR = MPHSTATE(MODEL,SOLTAG,'out',{'SP1','SP2',...}) returns a MATLAB
%   structure STR containing the state space matrices SP1, SP2, ... 
%   assembled using the solver node defined with the tag SOLTAG and 
%   accessible as STR.SP1 and STR.SP2. SP1 and SP2 being taken from the Out
%   property list.
% 
%   Valid property/value pairs include:
%   Property     Value/{Default}             Description
%   -----------------------------------------------------------------------
%   out          'MA'                        McA matrix
%                'MB'                        McB matrix
%                'A'                         A matrix
%                'B'                         B matrix
%                'C'                         C matrix
%                'D'                         D matrix
%                'Mc'                        Mc matrix
%                'Null'                      Null matrix
%                'ud'                        ud vector
%                'x0'                        x0 vector
%   keepfeature  {'off'} | 'on'              Keep the StateSpace feature in
%                                            the model 
%   input        String                      Input variables
%   output       String                      Output variables
%   sparse       {'off'} | 'on'              Return sparse matrices
%   initmethod   {'init'} | 'sol'            Use linearization point                  
%   initsol      {soltag} | 'zero'           Solution to use for linearization
%   solnum        {'auto'} | 'first' | 	      Solution number
%				  'last' | 'interp' |
%			      'manual' | Positive integer
%   variables    {first Dependent Variables} Dependent Variables node to
%                                            use   
% 
%   The property sparse controls whether the matrices A, B, C, D, M, MA, MB,
%   and Null are stored in the sparse format.
%   The input cannot be a variable constraint in the model.
% 
%   See the entry MPHSTATE in the LiveLink for MATLAB User's Guide for more 
%   information about the property/values.

%   Copyright 2010-2019 COMSOL
