function mphwritestl(filename, pd, format)
% MPHWRITESTL Export plot data as an STL file
%
%   MPHWRITESTL(FILENAME, PD) exports data in the plot data structure PD as 
%   the STL file FILENAME using the ASCII file format.
%
%   MPHWRITESTL(FILENAME, PD, '-binary') exports data in the plot data 
%   structure PD as the STL file FILENAME using the binary file format.
%
%   PD is a structure with the following fields:
%   Field         Description
%   -----------------------------------------------------------------------
%   p             The node point coordinate information.
%   t             The indices to columns in p of a simplex mesh, each column
%                 in t representing a simplex.
%
%   Other fields in the plot data structure are not considered to generate
%   the surface mesh.
%
%   Example: 
%     % Generate a surface mesh from solution plot:
%     model = mphopen('vacuum_flask_llmatlab'); 
%     pd = mphplot(model, 'pg1');
%     pd2stl = pd{2}{1};
%     mphwritestl('vacuumflask.stl', pd2stl)
%
%     % Generate a surface mesh from an existing volume mesh
%     model = mphopen('model_tutorial_llmatlab');
%     model.mesh('mesh1').run;
%     [s,d] = mphmeshstats(model, 'mesh1');
%     idx = strcmp(s.types, 'tri');
%     pdmesh.p = d.vertex;
%     pdmesh.t = d.elem{idx};
%     mphwritestl('mesh2geom.stl', pdmesh);
%
%   See also: mphquad2tri, mphreadstl, mphsurf

% Copyright 2012-2019 COMSOL
